@@ -157,7 +157,10 @@ class API(object):
 		if response.status_code != 200:
 			try:
 				data = response.json()
-				raise APIError(code = data['errors'][0]['code'], description = data['errors'][0]['message'])
+				try:
+					raise APIError(code = data['errors'][0]['code'], description = data['errors'][0]['message'])
+				except TypeError:
+					raise APIError(code = -1, description = data['errors'])
 			except APIError:
 				raise
 			except:
@@ -172,7 +175,7 @@ class API(object):
 		else:
 			return response.text
 	
-	def request_token(self):
+	def get_request_token(self):
 		url = self.build_request_url(self.oauth_root, 'request_token')
 		resp = self.do_request("GET", url, is_json = False)
 		token_data = self.parse_qs(resp)
@@ -181,7 +184,7 @@ class API(object):
 	
 	def get_auth_url(self, token = None):
 		if token is None:
-			token, secret = self.request_token()
+			token, secret = self.get_request_token()
 		return self.build_request_url(self.oauth_root, 'authenticate', {'oauth_token': token})
 	
 	def authenticate(self, verifier):
@@ -196,10 +199,8 @@ class API(object):
 			value = "true" if value else "false"
 		elif type(value) == list:
 			value = ",".join([str(val) for val in value])
-		elif type(value) != str and value is not None:
-			value = str(value)
-		if type(key) != str:
-			key = str(key)
+		elif type(value) not in [str, unicode] and value is not None:
+			value = unicode(value)
 		return (key, value)
 	
 	def parse_params(self, params):
